@@ -56,6 +56,7 @@ pub mod php;
 pub mod pulumi;
 pub mod purescript;
 pub mod python;
+pub mod raku;
 pub mod red;
 pub mod rlang;
 pub mod ruby;
@@ -198,6 +199,8 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     python: python::PythonConfig<'a>,
     #[serde(borrow)]
+    raku: raku::RakuConfig<'a>,
+    #[serde(borrow)]
     red: red::RedConfig<'a>,
     #[serde(borrow)]
     rlang: rlang::RLangConfig<'a>,
